Module server

Module server 

Structs

RPCServer
RPCServer manages a registry of handlers and dispatches incoming raw Lisp RPC strings

Traits

AsyncRpcFunc
A trait that captures the relationship between a request type T and its async response.
AsyncRpcHandler
The type-erased async handler trait
RpcFunc
A trait that captures the relationship between a request type T and its response.
RpcHandler
The type-erased handler trait